# Reviewer

Reviewer automates reviews of Drupal configuration to help developers catch 
build issues and decrease the time spent checking configuration forms.

For a full description of the module, visit the
[project page](https://www.drupal.org/project/reviewer).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/search/reviewer).

## Requirements

Reviewer requires [Drush](https://www.drush.org).

## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).

## Configuration

Reviewer requires no configuration. It is recommended to enable reviewer on
development environments only using
[Configuration Split](https://www.drupal.org/project/config_split).

## Usage

Reviewer provides the following Drush commands:

- `reviewer:list` 
- `reviewer:run`

Use the `--help` flag to see available options.

### reviewer:list

Lists all available reviews.

### reviewer:run

Runs reviews. By default, running reviews will output all failures (tests which 
did not pass) and errors (tests which threw an exception).

You may specify specific reviews to run by their ID. For example, 
`reviewer:run node paragraph` runs the "node" and "paragraph" reviews. For 
reviews that support bundles you can specify specific bundles to run. 
`reviewer:run node:article,page` runs the "node" review on "article" and "page"
content types only.

#### Options

- `--review`: Interactively review, prompting to ignore failures and errors.
- `--review-new`: Interactively review, prompting to ignore new failures and 
  errors only.
- `--review-reset`: Interactively review, prompting to ignore all failures and 
  errors. Any previously ignored items will no longer be ignored.
- `--show-passed`: Display passed tests in addition to failures and errors.
- `--show-ignored`: Display ignored tests in addition to failures and errors.
- `--show-all`: Display ignored and passed tests in addition to failures and 
  errors.
- `--window-width`: Set the window width to constrain the output table size.
  Defaults to 80.

## Creating Reviews, Checklists, and Tasks

Reviews are plugins which represent a single type of configuration to review.
For example, a `node` review which checks configuration on all node types.

Each review must contain at least one checklist plugin. Checklists are smaller 
groupings of tasks which can be reused across reviews. For example, a 
`search_index` checklist which ensures that the search index display mode is
configured and that it has all field labels set to hidden. The `search_index`
checklist is then added to the `node`, `taxonomy_term`, and `paragraph` reviews.

Checklists contain any number of tasks. Tasks are the individual items run 
in each checklist. Tasks contain a callable check which must return either a 
boolean (for single results), or an array of booleans.

The `reviewer_test` module has examples of review and checklists plugins. 

## Maintainers

Current maintainer:
- [Benjamin Baird (benabaird)](https://www.drupal.org/u/benabaird)
