<?php

declare(strict_types=1);

namespace Drupal\reviewer\Reviewer;

use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\reviewer\Plugin\reviewer\Review\EntityReviewPluginInterface;
use Drupal\reviewer\Reviewer\Review\ReviewInterface;

/**
 * Evaluates bundles.
 */
final readonly class BundleEvaluator implements BundleEvaluatorInterface {

  // phpcs:ignore Drupal.Commenting.FunctionComment.Missing
  public function __construct(
    private EntityTypeBundleInfoInterface $entityTypeBundleInfo,
    private EntityTypeManagerInterface $entityTypeManager,
  ) {}

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   */
  public function allBundles(EntityReviewPluginInterface $review_plugin): array {
    if ($bundles = $review_plugin->getBundles()) {
      return $bundles;
    }

    if (!$review_plugin->getEntityType()) {
      return [$review_plugin->getEntityId()];
    }

    $entity_type = $this
      ->entityTypeManager
      ->getStorage($review_plugin->getEntityType())
      ->getEntityType();

    $bundles = $this
      ->entityTypeBundleInfo
      ->getBundleInfo($entity_type->getBundleOf());

    return count($bundles) === 1 && array_key_first($bundles) === $review_plugin->getEntityType()
      ? []
      : array_keys($bundles);
  }

  /**
   * {@inheritdoc}
   */
  public function reviewHasBundle(
    ReviewInterface $review,
    array $bundles,
  ): bool {
    return str_contains($review->getId(), '.')
      && \in_array(explode('.', $review->getId())[1], $bundles);
  }

  /**
   * {@inheritdoc}
   */
  public function reviewsOfBundles(
    array $reviews,
    array $bundles,
  ): array {
    return $bundles
      ? array_filter(
        $reviews,
        fn(ReviewInterface $review) => $this->reviewHasBundle($review, $bundles),
      )
      : $reviews;
  }

}
