<?php

namespace Drupal\reviewer\Reviewer;

use Drupal\reviewer\Reviewer\Result\ResultInterface;

/**
 * Defines a class which ignores review results.
 */
interface IgnorerInterface {

  /**
   * Check if a result is in the list of ignored results.
   */
  public function isIgnored(ResultInterface|string $result): bool;

  /**
   * Check if a result is in the list of results ignored in plugin attributes.
   */
  public function isPluginIgnored(ResultInterface|string $result): bool;

  /**
   * Check if a result is in the list of results ignored in configuration.
   */
  public function isConfigIgnored(ResultInterface|string $result): bool;

  /**
   * Get the reason an item was ignored.
   *
   * @throws \Drupal\reviewer\Exception\NotIgnoredException
   */
  public function ignoredReason(ResultInterface|string $result): string;

  /**
   * Return results in the list of ignored results from a set of results.
   *
   * @param \Drupal\reviewer\Reviewer\Result\ResultInterface[] $results
   *
   * @return \Drupal\reviewer\Reviewer\Result\ResultInterface[]
   */
  public function ignoredResults(array $results): array;

  /**
   * Return results not in the list of ignored results from a set of results.
   *
   * @param \Drupal\reviewer\Reviewer\Result\ResultInterface[] $results
   *
   * @return \Drupal\reviewer\Reviewer\Result\ResultInterface[]
   */
  public function unignoredResults(array $results): array;

  /**
   * Add a result to the list of ignored results.
   */
  public function ignore(ResultInterface $result, string $reason = ''): void;

  /**
   * Remove a result from the list of ignored results.
   *
   * @param \Drupal\reviewer\Reviewer\Result\ResultInterface[]|\Drupal\reviewer\Reviewer\Result\ResultInterface $results
   */
  public function unignore(ResultInterface|array $results): void;

}
