<?php

declare(strict_types=1);

namespace Drupal\reviewer\Reviewer\Task;

use Drupal\Core\Config\ConfigManagerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\reviewer\Plugin\reviewer\Review\EntityReviewPluginInterface;
use Drupal\reviewer\Plugin\reviewer\Review\ReviewPluginInterface;

/**
 * Creates task configuration value objects.
 */
final readonly class TaskConfigFactory implements TaskConfigFactoryInterface {

  // phpcs:ignore Drupal.Commenting.FunctionComment.Missing
  public function __construct(
    private ConfigManagerInterface $configManager,
    private EntityTypeManagerInterface $entityTypeManager,
  ) {}

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function create(
    ReviewPluginInterface $review,
    string $bundle = '',
  ): TaskConfigInterface {
    $configuration = [];
    foreach ($review->getConfiguration() as $id) {
      $config = $this->configManager->getConfigFactory()->get($id);
      $configuration[$id] = $config->getRawData()
        ? $config
        : $this->configManager->loadConfigEntityByName($id);
    }

    $entity = NULL;
    if ($review instanceof EntityReviewPluginInterface) {
      if ($review->getEntityId()) {
        $entity = $this->configManager->loadConfigEntityByName($review->getEntityId());
      }
      elseif ($review->getEntityType()) {
        $entity = $bundle
          ? $this
            ->entityTypeManager
            ->getStorage($review->getEntityType())
            ->load($bundle)
          : throw new \InvalidArgumentException(sprintf(
            'Parameter $bundle must be a non-empty string when parameter $review is an instance of %s.',
            EntityReviewPluginInterface::class,
          ));
      }
    }
    /** @var \Drupal\Core\Config\Entity\ConfigEntityInterface|null $entity */

    return new TaskConfig($configuration, $entity);
  }

}
