<?php

declare(strict_types=1);

namespace Drupal\reviewer_test\Plugin\reviewer\Checklist;

use Drupal\reviewer\Attribute\Checklist;
use Drupal\reviewer\Plugin\reviewer\Checklist\ChecklistBase;

/**
 * Test task returns.
 */
#[Checklist(
  id: 'returns_tests',
  label: 'Returns Tests',
)]
final class ReturnsTests extends ChecklistBase {

  /**
   * {@inheritdoc}
   */
  public function tasks(): array {
    return [
      $this->taskFactory->create('array_valid', $this->arrayValid(...), 'Failures: @failures'),
      $this->taskFactory->create('array_error', $this->arrayError(...), 'Array error'),
      $this->taskFactory->create('bool_pass', $this->booleanPass(...), 'Pass'),
      $this->taskFactory->create('bool_fail', $this->booleanFail(...), 'Fail'),
      $this->taskFactory->create('error', $this->error(...), 'Return error'),
    ];
  }

  /**
   * Test a valid return array.
   *
   * @return array<string, bool>
   */
  private function arrayValid(): array {
    return [
      'one' => FALSE,
      'two' => TRUE,
      'three' => FALSE,
    ];
  }

  /**
   * Test an invalid return array.
   *
   * @return array<string, int>
   */
  private function arrayError(): array {
    return [
      'one' => 1,
    ];
  }

  /**
   * Test a pass return.
   */
  private function booleanPass(): bool {
    return TRUE;
  }

  /**
   * Test a failure return.
   */
  private function booleanFail(): bool {
    return FALSE;
  }

  /**
   * Test an invalid return value.
   */
  private function error(): string {
    return 'hello';
  }

}
