<?php

declare(strict_types=1);

namespace Drupal\Tests\reviewer\Functional\Drush;

use Drupal\Tests\BrowserTestBase;
use Drush\TestTraits\DrushTestTrait;

/**
 * Test Drush commands.
 *
 * @coversDefaultClass \Drupal\reviewer\Drush\Commands\ReviewerCommands
 */
class DrushTest extends BrowserTestBase {

  use DrushTestTrait {
    drush as drushTrait;
  }

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'reviewer',
    'reviewer_test',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Test the reviewer:run command.
   *
   * @todo Figure out how to test interactive input.
   *
   * @covers ::run
   */
  public function testRun(): void {
    $this->drush('reviewer:run');
    $output = $this->getOutput();
    $this->assertStringContainsString('Site Settings Test', $output);
    $this->assertStringContainsString('Returns Tests', $output);
    $this->assertStringContainsString('Node Test: Node (Fail Review)', $output);
    $this->assertStringContainsString('Taxonomy Test: Taxonomy (Fail Review)', $output);
    $this->assertStringNotContainsString('Node Test: Taxonomy (Pass Review)', $output);
    $this->assertStringNotContainsString('Taxonomy Test: Taxonomy (Pass Review)', $output);
    $this->assertStringContainsString('Error', $output);
    $this->assertStringContainsString('Failed', $output);
    $this->assertStringNotContainsString('Pass', $output);
    $this->assertStringNotContainsString('Ignored', $output);

    $this->drush('reviewer:run --show-passed');
    $output = $this->getOutput();
    $this->assertStringContainsString('Node Test: Node (Pass Review)', $output);
    $this->assertStringContainsString('Taxonomy Test: Taxonomy (Pass Review)', $output);
    $this->assertStringContainsString('Pass', $output);
    $this->assertStringNotContainsString('Ignored', $output);

    $this->drush('reviewer:run --show-ignored');
    $output = $this->getOutput();
    $this->assertStringContainsString('Ignored Error', $output);
    $this->assertStringContainsString('Ignored Failure', $output);
    $this->assertStringNotContainsString('Pass', $output);

    $this->drush('reviewer:run --show-all');
    $output = $this->getOutput();
    $this->assertStringContainsString('Node Test: Node (Pass Review)', $output);
    $this->assertStringContainsString('Taxonomy Test: Taxonomy (Pass Review)', $output);
    $this->assertStringContainsString('Pass', $output);
    $this->assertStringContainsString('Ignored Error', $output);
    $this->assertStringContainsString('Ignored Failure', $output);

    $this->drush('reviewer:run node_tests:node_fail --show-all');
    $output = $this->getOutput();
    $this->assertStringContainsString('Node Test: Node (Fail Review)', $output);
    $this->assertStringNotContainsString('Node Test: Node (Pass Review)', $output);
    $this->assertStringNotContainsString('Taxonomy Test: Taxonomy (Fail Review)', $output);
    $this->assertStringNotContainsString('Taxonomy Test: Taxonomy (Pass Review)', $output);
    $this->assertStringNotContainsString('Site Settings Test', $output);
    $this->assertStringNotContainsString('Returns Tests', $output);

    $this->drush('reviewer:run node_tests:node_fail,node_pass taxonomy_tests:taxonomy_pass returns_tests --show-all');
    $output = $this->getOutput();
    $this->assertStringContainsString('Returns Tests', $output);
    $this->assertStringContainsString('Node Test: Node (Fail Review)', $output);
    $this->assertStringContainsString('Node Test: Node (Pass Review)', $output);
    $this->assertStringContainsString('Taxonomy Test: Taxonomy (Pass Review)', $output);
    $this->assertStringNotContainsString('Taxonomy Test: Taxonomy (Fail Review)', $output);
    $this->assertStringNotContainsString('Site Settings Test', $output);
  }

  /**
   * Test the reviewer:list command.
   *
   * @covers ::list
   */
  public function testList(): void {
    $this->drush('reviewer:list');
    $output = $this->getOutput();
    $this->assertStringContainsString('ID', $output);
    $this->assertStringContainsString('Label', $output);
    $this->assertStringContainsString('review_test', $output);
    $this->assertStringContainsString('Site Settings Test', $output);
    $this->assertStringContainsString('returns_tests', $output);
    $this->assertStringContainsString('Returns Tests', $output);
    $this->assertStringContainsString('taxonomy_tests', $output);
    $this->assertStringContainsString('Taxonomy Test', $output);
    $this->assertStringContainsString('node_tests', $output);
    $this->assertStringContainsString('Node Test', $output);

    $this->container->get('module_installer')->uninstall(['reviewer_test']);
    $this->drush('reviewer:list');
    $output = $this->getOutput();
    $this->assertStringContainsString('ID', $output);
    $this->assertStringContainsString('Label', $output);
    $this->assertStringNotContainsString('review_test', $output);
    $this->assertStringNotContainsString('Site Settings Test', $output);
    $this->assertStringNotContainsString('returns_tests', $output);
    $this->assertStringNotContainsString('Returns Tests', $output);
    $this->assertStringNotContainsString('taxonomy_tests', $output);
    $this->assertStringNotContainsString('Taxonomy Test', $output);
    $this->assertStringNotContainsString('node_tests', $output);
    $this->assertStringNotContainsString('Node Test', $output);
  }

}
